function [D] = KLdiv(M1,M2)
%
% [D] = KLdiv(M1,M2)
%
% Compute matrix of KL divergences between examples in 2 datasets
% 
% Inputs:
%   M1:     cell array of means and covariances for each example
%           in 1st dataset
%   M2:     cell array of means and covariances for each example
%           in 2nd dataset
%
% Outputs:
%   D:      matrix of pairwise KL divergences
%           (# examples in M1 x # examples in M2)
%
% 2010/11/30 Courtenay Cotton (cvcotton@ee.columbia.edu)

nSamp1 = length(M1);
nSamp2 = length(M2);
nDim = length(M1{1}.mu);

% Dist matrix
D = zeros(nSamp1,nSamp2);

% Pairwise KL divergences:
for i = 1:nSamp1
    
    E1 = M1{i};
    iSig1 = inv(E1.sigma);
    
    for j = 1:nSamp2
        
        E2 = M2{j};
        iSig2 = inv(E2.sigma);
        
        dM = E1.mu - E2.mu;
        
        D(i,j) = (dM * (iSig1 + iSig2) * dM') + trace(iSig1*E2.sigma + iSig2*E1.sigma) - 2*nDim;

    end
end


