function [ftrSet,labels] = collectData(setList,labels,nameList,ftrs)
%
% [ftrsSet,labels] = collectData(setList,labels,nameList,ftrs)
%
% For each file in setList, find the match in the full nameList of files 
% and collect its features, if they exist
%
% Inputs:
%   setList:    list of files to collect features for
%   labels:     matrix of binary labels for files in setList
%   nameList:   list of all audio files
%   ftrs:       cell array of features for files in nameList
%
% Outputs:
%   ftrSet:     cell array of features corresponding to files in setList
%   labels:     matrix of binary labels for files in setList
%
% 2010/11/30 Courtenay Cotton (cvcotton@ee.columbia.edu)

% Vector of flags to ensure each file exists in the full list and has features
hasFtrs = [];

ftrSet = cell(length(setList),1);

% Match each file name in setList
for i = 1:length(setList)
    
    idx = find(strcmp(setList{i},nameList));
    
    if( ~isempty(idx) )
        
        if( ~isempty(ftrs{idx}.mu) )
            ftrSet{i} = ftrs{idx};
            hasFtrs = [hasFtrs; i];
        end
    end
end

% Remove nonexistant examples from ftrs and labels
ftrSet = ftrSet(hasFtrs);
labels = labels(hasFtrs,:);



