function [AP] = evalAP(decisionVal,trueLabels,labelMap)
%
% [AP] = evalAP(decisionVal,trueLabels,labelMap)
%
% Compute average precision value on a set of examples, based on
% ranking them by SVM decision values
% 
% Inputs:
%   decisionVal:    SVM decision values
%   trueLabels:     ground truth labels for these points
%   labelMap:       mapping of positive/negative decision values to
%                   actual labels (from svm_model.Label)
%
% Outputs:
%   AP:     average precision over these points
%
% 2010/11/30 Courtenay Cotton (cvcotton@ee.columbia.edu)

% Reverse decision values if labelMap started with negative (= +1 internally)
if( labelMap(1) == 0 )
    decisionVal = -1*decisionVal;
end

% Rank decision values (top = most likely to be given positive label):
[v,idx] = sort(decisionVal,'descend');

% Reorder labels to match sorted decision values:
sortLabels = trueLabels(idx);

% Total number of positive labels:
nPos = sum(trueLabels);

% At the level of each positive (=1) label, evaluate precision:
nFromTop = find(sortLabels == 1);
prec = zeros(nPos,1);
for i = 1:length(nFromTop)
    % At this level, evaluate precision = (# true / total #)
    prec(i) = sum(sortLabels(1:nFromTop(i))) / nFromTop(i);
end

% Average precision over total number of positive examples:
AP = sum(prec) / nPos;



