function [fileList] = getFileList(files)
%
% [fileList] = getFileList(files)
%
% Get list of audio files to process (full paths) 
%
% Inputs:
%   files:  either a list of audio files to process ('list.txt')
%           or a directory name containing the files ('~/data/audioFiles/')
%
% Outputs:
%   fileList:   cell array of audio files found (.wav or .mp3)
%
% 2010/11/30 Courtenay Cotton (cvcotton@ee.columbia.edu)

fileList = [];

% If 'files' is a list of files, read;
% else if 'files' is a dir, get all audio files in dir
if( exist(files,'file') == 2 )
    fid = fopen(files);
    fileList = textscan(fid,'%s ');
    fileList = fileList{1};
    fclose(fid);
elseif( exist(files,'dir') == 7 )
    wavFiles = dir(fullfile(files,'*.wav'));
    mp3Files = dir(fullfile(files,'*.mp3'));
    allFiles = [wavFiles; mp3Files];
    fileList = cell(length(allFiles),1);
    for i = 1:length(allFiles)
        fileList{i} = fullfile(files,allFiles(i).name);
    end
else
    error(['Cannot find file or directory: ',files]);
end

