function [D] = mahalDist(M1,M2)
%
% [D] = mahalDist(M1,M2)
%
% Compute Mahalanobis distance matrix for examples in matrices M1 and M2,
% using the variance of M2 (which should be the training data)
% 
% Inputs:
%   M1:      matrix of (# examples x # ftrs) data
%   M2:      matrix of (# examples x # ftrs) data, should be training set
%
% Outputs:
%   D:       matrix of pairwise distances
%            (# examples in M1 x # examples in M2)
%
% 2010/11/30 Courtenay Cotton (cvcotton@ee.columbia.edu)

% Find (diagonal) covariance of training data (2nd matrix):
trainVar = diag(cov(M2))';

% Distance matrix:
nSamp1 = size(M1,1);
nSamp2 = size(M2,1);
D = zeros(nSamp1,nSamp2);

% Pairwise distances (Mahalanobis = variance-normalized Euclidean):
for i = 1:nSamp1
    for j = 1:nSamp2
        D(i,j) = sum( (M1(i,:) - M2(j,:)).^2 ./ trainVar );
    end
end
D = sqrt(D);


