function [ftrMtx] = makeFtrMtx(data)
%
% [ftrMtx] = makeFtrMtx(data)
%
% Take mu and sigma values from data array and concatenate into a feature
% matrix
%
% Inputs:
%   data:   cell array of mean and covariance for a set of files
%
% Outputs:
%   ftrMtx:     matrix of (# files x # ftrs) containing
%               mean and unique covariance values concatenated together
%
% 2010/11/30 Courtenay Cotton (cvcotton@ee.columbia.edu)

% Pre-allocate to correct size (check # dims in first file)
tmp = data{1};
nDim = length(tmp.mu) + length(tmp.mu)*(length(tmp.mu)+1)/2;
ftrMtx = zeros(length(data),nDim);

% Collect [mu, unique cov values]
for i = 1:length(data)
    tmp = data{i};
    uniqCov = triu(tmp.sigma);
    uniqCov = nonzeros(uniqCov)';
    ftrMtx(i,:) = [tmp.mu, uniqCov];
end

